﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ConverTemps.Clases;
using System.ComponentModel;

namespace ConverTemps
{
  /// <summary>
  /// Lógica de interacción para MainWindow.xaml
  /// </summary>
  public partial class MainWindow : Window
  {
    private TextBox objTextBox = null;
    private CGrados objGrados = new CGrados();

    public MainWindow()
    {
      InitializeComponent();
      ctGradosC.Text = string.Format("{0:F2}", objGrados.GradosC);
      ctGradosF.Text = string.Format("{0:F2}", objGrados.GradosF);
      objGrados.PropertyChanged += objGrados_PropertyChanged;
    }

    private void objGrados_PropertyChanged(object sender, PropertyChangedEventArgs e)
    {
      switch (e.PropertyName)
      {
        case "GradosC":
          ctGradosC.Text = string.Format("{0:F2}", objGrados.GradosC);
          break;
        case "GradosF":
          ctGradosF.Text = string.Format("{0:F2}", objGrados.GradosF);
          break;
      }
    }

    private void formPrincipal_Loaded(object sender, RoutedEventArgs e)
    {
      ctGradosC.Focus();
    }

    private void ctGradosC_GotKeyboardFocus(object sender, KeyboardFocusChangedEventArgs e)
    {
      TextBox ObjTextBox = sender as TextBox;
      ObjTextBox.SelectAll();
    }

    private void ctGradosF_GotKeyboardFocus(object sender, KeyboardFocusChangedEventArgs e)
    {
      TextBox ObjTextBox = sender as TextBox;
      ObjTextBox.SelectAll();
    }

    private void btAceptar_Click(object sender, RoutedEventArgs e)
    {
      Conversion();
    }

    private void Conversion()
    {
      try
      {
        double grados;
        // Si se escribió en la caja de texto grados centígrados...
        if (objTextBox == ctGradosC)
        {
          grados = Convert.ToDouble(ctGradosC.Text) * 9.0 / 5.0 + 32.0;
          // Mostrar el resultado redondeado a dos decimales
          ctGradosF.Text = string.Format("{0:F2}", grados);
        }
        // Si se escribió en la caja de texto grados Fahrenheit...
        if (objTextBox == ctGradosF)
        {
          grados = (Convert.ToDouble(ctGradosF.Text) - 32.0) * 5.0 / 9.0;
          // Mostrar el resultado redondeado a dos decimales
          ctGradosC.Text = string.Format("{0:F2}", grados);
        }
      }
      catch (FormatException)
      {
        ctGradosC.Text = "0,00";
        ctGradosF.Text = "32,00";
      }
    }

    private void ctGradosC_PreviewTextInput(object sender, TextCompositionEventArgs e)
    {
      ValidarTecla(sender, e);
      objTextBox = sender as TextBox;
    }

    private void ctGradosF_PreviewTextInput(object sender, TextCompositionEventArgs e)
    {
      ValidarTecla(sender, e);
      objTextBox = sender as TextBox;
    }

    private void ValidarTecla(object sender, TextCompositionEventArgs e)
    {
      if (e.Text == ",")
      {
        TextBox ObjTextBox = (TextBox)e.Source;
        if (ObjTextBox.Text.IndexOf(',') != -1)
        {
          // Sólo puede haber una coma
          e.Handled = true;
        }
      }
      else if (e.Text == "-" || e.Text == "+")
      {
        TextBox ObjTextBox = (TextBox)e.Source;
        // Admitir - o + sólo en la primera posición:
        if (ObjTextBox.SelectionLength == ObjTextBox.Text.Length)
        {
          // Todo el texto está seleccionado: se sobrescribe con el signo
          e.Handled = false;
        }
        else if (ObjTextBox.Text.Length != 0)
        {
          // La primera posición ya está ocupada
          e.Handled = true;
        }
      }
      else if (e.Text.CompareTo("0") < 0 || e.Text.CompareTo("9") > 0)
      {
        // Desechar los caracteres que no son dígitos
        e.Handled = true;
      }
    }

    private void btSiguiente_Click(object sender, RoutedEventArgs e)
    {
      objGrados.GradosC++;
      objGrados.GradosF = objGrados.GradosC * 9.0 / 5.0 + 32.0;
      MessageBox.Show(string.Format("{0:F2} ºC --> {1:F2} ºF", objGrados.GradosC, objGrados.GradosF));
    }

    private void ctGradosC_TextChanged(object sender, TextChangedEventArgs e)
    {
      double gradosC = 0;
      if (Double.TryParse(ctGradosC.Text, out gradosC))
        objGrados.GradosC = gradosC;
    }

    private void ctGradosF_TextChanged(object sender, TextChangedEventArgs e)
    {
      double gradosF = 0;
      if (Double.TryParse(ctGradosF.Text, out gradosF))
        objGrados.GradosF = gradosF;
    }
  }
}
