﻿using System.ComponentModel;
using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace BaseDeDatos
{
  public class Alumno : INotifyPropertyChanged
  {
    private int _idAlumno;
    public int IdAlumno
    {
      get { return _idAlumno; }
      set
      {
        _idAlumno = value;
        OnPropertyChanged(new PropertyChangedEventArgs("IdAlumno"));
      }
    }

    private string _nomAlumno;
    public string NomAlumno
    {
      get { return _nomAlumno; }
      set
      {
        _nomAlumno = value;
        OnPropertyChanged(new PropertyChangedEventArgs("NomAlumno"));
      }
    }

    private string _dirAlumno;
    public string DirAlumno
    {
      get { return _dirAlumno; }
      set
      {
        _dirAlumno = value;
        OnPropertyChanged(new PropertyChangedEventArgs("DirAlumno"));
      }
    }

    private string _estAlumno;
    public string EstAlumno
    {
      get { return _estAlumno; }
      set
      {
        _estAlumno = value;
        OnPropertyChanged(new PropertyChangedEventArgs("EstAlumno"));
      }
    }

    private bool _becaAlumno;
    public bool BecaAlumno
    {
      get { return _becaAlumno; }
      set
      {
        _becaAlumno = value;
        OnPropertyChanged(new PropertyChangedEventArgs("BecaAlumno"));
      }
    }

    private ObservableCollection<Asignaturas> _listaCoAsignaturas;
    public ObservableCollection<Asignaturas> ListaCoAsignaturas
    {
      get { return _listaCoAsignaturas; }
      set
      {
        _listaCoAsignaturas = value;
        OnPropertyChanged(new PropertyChangedEventArgs("ListaCoAsignaturas"));
      }
    }

    private ObservableCollection<Asignatura> _listaAsigsObs;
    public ObservableCollection<Asignatura> ListaAsigsObs
    {
      get
      {
        _listaAsigsObs = ObtenerAsigsObsOps("Obligatorias");
        return _listaAsigsObs;
      }
      set
      {
        _listaAsigsObs = value;
        OnPropertyChanged(new PropertyChangedEventArgs("ListaAsigsObs"));
      }
    }

    private ObservableCollection<Asignatura> _listaAsigsOps;
    public ObservableCollection<Asignatura> ListaAsigsOps
    {
      get
      {
        _listaAsigsOps = ObtenerAsigsObsOps("Optativas");
        return _listaAsigsOps;
      }
      set
      {
        _listaAsigsOps = value;
        OnPropertyChanged(new PropertyChangedEventArgs("ListaAsigsOps"));
      }
    }

    private ObservableCollection<Asignatura> ObtenerAsigsObsOps(string tipo)
    {
      if (_listaCoAsignaturas != null)
        foreach (Asignaturas asigs in _listaCoAsignaturas)
          if (asigs.Tipo == tipo)
            return asigs.ListaAsignaturas;
      return null;
    }

    public Asignatura ObtenerAsignatura(int idAsig)
    {
      ObservableCollection<Asignatura> colAsigs;
      // Obligatorias
      colAsigs = ListaAsigsObs;
      if (colAsigs != null)
        foreach (Asignatura asig in colAsigs)
          if (asig.IdAsignatura == idAsig) return asig;
      // Optativas
      colAsigs = ListaAsigsOps;
      if (colAsigs != null)
        foreach (Asignatura asig in colAsigs)
          if (asig.IdAsignatura == idAsig) return asig;
      return null;
    }

    public event PropertyChangedEventHandler PropertyChanged;
    public void OnPropertyChanged(PropertyChangedEventArgs e)
    {
      if (PropertyChanged != null)
        PropertyChanged(this, e); // generar evento
    }

    public override string ToString()
    {
      return NomAlumno;
    }

    public Alumno()
    {
      IdAlumno = 123;
      NomAlumno = "¿Nombre?";
      DirAlumno = "¿Dirección?";
      EstAlumno = "¿Estudios?";
      BecaAlumno = false;
      ListaCoAsignaturas = new ObservableCollection<Asignaturas>();
    }

    public Alumno(int id, string nom, string dir, string est, bool beca, ObservableCollection<Asignaturas> lista)
    {
      IdAlumno = id;
      NomAlumno = nom;
      DirAlumno = dir;
      EstAlumno = est;
      BecaAlumno = beca;
      ListaCoAsignaturas = lista;
    }
  }
}
