﻿using System.Text;
using System.Windows;
using System.Windows.Data;
using System.ComponentModel;
using BaseDeDatos;
using System.Collections.ObjectModel;


namespace EnlaceDeDatosObjetos
{
  /// <summary>
  /// Lógica de interacción para DlgInsertarBorrar.xaml
  /// </summary>
  public partial class DlgInsertarBorrar : Window
  {
    public DlgInsertarBorrar()
    {
      InitializeComponent();
    }

    private ICollectionView ObtenerVista()
    {
      return CollectionViewSource.GetDefaultView(listaAlumnos.ItemsSource);
    }

    private void btMostrarOb_Click(object sender, RoutedEventArgs e)
    {
      MostrarAsigs("Obligatorias");
    }

    private void btMostrarOp_Click(object sender, RoutedEventArgs e)
    {
      MostrarAsigs("Optativas");
    }

    private void MostrarAsigs(string tipo)
    {
      ICollectionView vista = ObtenerVista();
      if (vista.IsEmpty) return;
      // Cada "alumno" es un objeto de la clase Alumno
      Alumno alumnoActual = (Alumno)vista.CurrentItem;
      ObservableCollection<Asignatura> list = null;
      if (tipo == "Obligatorias")
        list = alumnoActual.ListaAsigsObs;
      else if (tipo == "Optativas")
        list = alumnoActual.ListaAsigsOps;
      else
        return;
      StringBuilder s = new StringBuilder();
      foreach (Asignatura asig in list)
        s.Append(asig.NomAsignatura + "\n");
      MessageBox.Show(s.ToString());
    }

    private void btSiguiente_Click(object sender, RoutedEventArgs e)
    {
      ICollectionView vista = ObtenerVista();
      vista.MoveCurrentToNext();
      if (vista.IsCurrentAfterLast) vista.MoveCurrentToLast();
      listaAlumnos.ScrollIntoView(vista.CurrentItem);
    }

    private void btAnterior_Click(object sender, RoutedEventArgs e)
    {
      ICollectionView vista = ObtenerVista();
      vista.MoveCurrentToPrevious();
      if (vista.IsCurrentBeforeFirst) vista.MoveCurrentToFirst();
      listaAlumnos.ScrollIntoView(vista.CurrentItem);
    }

    private void cvOrdenar_Click(object sender, RoutedEventArgs e)
    {
      ICollectionView vista = ObtenerVista();
      if (vista.CanSort && cvOrdenar.IsChecked == true)
      {
        if (vista.SortDescriptions.Count == 0)
        {
          vista.SortDescriptions.Add(
            new SortDescription("BecaAlumno", ListSortDirection.Descending));
          vista.SortDescriptions.Add(
            new SortDescription("NombAlumno", ListSortDirection.Ascending));
        }
      }
      else
        vista.SortDescriptions.Clear();
    }

    private void cvFiltrar_Click(object sender, RoutedEventArgs e)
    {
      ICollectionView vista = ObtenerVista();
      if (vista.CanFilter && cvFiltrar.IsChecked == true)
      {
        if (vista.Filter == null)
          vista.Filter = delegate(object elemento)
          {
            return ((Alumno)elemento).BecaAlumno == true;
          };
      }
      else
        vista.Filter = null;
    }

    private void cvAgrupar_Click(object sender, RoutedEventArgs e)
    {
      ICollectionView vista = ObtenerVista();
      if (vista.CanGroup && cvAgrupar.IsChecked == true)
      {
        if (vista.GroupDescriptions.Count == 0)
        {
          // Agrupar por BecaAlumno
          vista.GroupDescriptions.Add(new PropertyGroupDescription("BecaAlumno"));
        }
      }
      else
        vista.GroupDescriptions.Clear();
    }

    private void btBorrar_Click(object sender, RoutedEventArgs e)
    {
      // Recuperar el recurso objBBDD de Application
      bbdd objBBDD = this.FindResource("objBBDD") as bbdd;
      objBBDD.Alumnos.Remove(listaAlumnos.SelectedItem as Alumno);
    }

    private void btAñadir_Click(object sender, RoutedEventArgs e)
    {
      Alumno nuevo = CrearNuevoAlumno();
      DlgAñadir dlg = new DlgAñadir(nuevo); //DlgBindingGroup dlg = new DlgBindingGroup(nuevo);
      if (dlg.ShowDialog() == true)
      {
        // Verificar si el IdAlumno existe en la colección
        bbdd objBBDD = this.FindResource("objBBDD") as bbdd;
        int id =int.Parse(dlg.ctIdAlumno.Text);
        if (objBBDD.ObtenerAlumnoPorId(id) != null)
        {
          MessageBox.Show(string.Format("El Id {0} ya existe", id));
          return;
        }
        // Añadir las asignaturas seleccionadas
        AñadirAsigs(nuevo, dlg);
        // Añadir el nuevo alumno a la colección
        objBBDD.Alumnos.Add(nuevo);
      }
    }

    private void AñadirAsigs(Alumno nuevo, DlgAñadir dlg) // private void AñadirAsigs(Alumno nuevo, DlgBindingGroup dlg)
    {
      // Añadir las asignaturas seleccionadas en las listas
      // a las colecciones correspondientes
      int id;
      string nombre;
      foreach (string s in dlg.lsListaObs.SelectedItems)
      {
        id = int.Parse(s.Substring(0, 2));
        nombre = s.Substring(3);
        nuevo.ListaAsigsObs.Add(new Asignatura(id, nombre, -1));
      }
      foreach (string s in dlg.lsListaOps.SelectedItems)
      {
        id = int.Parse(s.Substring(0, 2));
        nombre = s.Substring(3);
        nuevo.ListaAsigsOps.Add(new Asignatura(id, nombre, -1));
      }
    }

    private Alumno CrearNuevoAlumno()
    {
      // Construir la colección de asignaturas
      ObservableCollection<Asignaturas> listaAsigs = new ObservableCollection<Asignaturas>();
      listaAsigs.Add(new Asignaturas("Obligatorias", new ObservableCollection<Asignatura>()));
      listaAsigs.Add(new Asignaturas("Optativas", new ObservableCollection<Asignatura>()));
      // Construir el objeto Alumno
      Alumno nuevo = new Alumno();
      nuevo.ListaCoAsignaturas = listaAsigs;
      return nuevo;
    }
  }
}
