﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Input;
using System.Windows.Navigation;
using System.ComponentModel;
using BDtelefonos;
using Microsoft.Win32;
using System.IO;
using System.Drawing;
using System.Drawing.Imaging;

namespace ApXBAPtelefonos
{
  /// <summary>
  /// Lógica de interacción para Page1.xaml
  /// </summary>
  public partial class PagMostrar : Page
  {
    private ObjectDataProvider odp = null;

    public PagMostrar()
    {
      InitializeComponent();
    }

    private void Page_Loaded(object sender, RoutedEventArgs e)
    {
      odp = (ObjectDataProvider)this.FindResource("pdTelefonos");
      this.DataContext = odp;
      // Manejar el evento CurrentChanged de la vista
      ICollectionView vista = ObtenerVista();
      vista.CurrentChanged += new EventHandler(vista_CurrentChanged);
      ActualizarPosicionReg(vista as CollectionView);
    }

    private ICollectionView ObtenerVista()
    {
      return CollectionViewSource.GetDefaultView(odp.Data);
    }

    private void vista_CurrentChanged(object sender, EventArgs e)
    {
      ActualizarPosicionReg(sender as CollectionView);
    }

    private void ActualizarPosicionReg(CollectionView vista)
    {
      if (vista.CurrentItem == null) return;
      string posicionActual = Convert.ToString(vista.CurrentPosition + 1);
      this.btxPosicionReg.Text = posicionActual;
      this.btxTotalReg.Text = vista.Count.ToString();
      // Poner una foto ficticia si este campo es null
      if ((vista.CurrentItem as telefono).foto != null) return;
      Bitmap fotoFicticia = Properties.Resources.unafoto;
      MemoryStream ms = new MemoryStream();
      fotoFicticia.Save(ms, ImageFormat.Jpeg);
      (vista.CurrentItem as telefono).foto = ms.ToArray();
    }

    private void btPrimero_Click(object sender, RoutedEventArgs e)
    {
      ICollectionView vista = ObtenerVista();
      vista.MoveCurrentToFirst();
    }

    private void btAnterior_Click(object sender, RoutedEventArgs e)
    {
      ICollectionView vista = ObtenerVista();
      vista.MoveCurrentToPrevious();
      if (vista.IsCurrentBeforeFirst) vista.MoveCurrentToFirst();
    }

    private void btSiguiente_Click(object sender, RoutedEventArgs e)
    {
      ICollectionView vista = ObtenerVista();
      vista.MoveCurrentToNext();
      if (vista.IsCurrentAfterLast) vista.MoveCurrentToLast();
    }

    private void btUltimo_Click(object sender, RoutedEventArgs e)
    {
      ICollectionView vista = ObtenerVista();
      vista.MoveCurrentToLast();
    }

    private void ucFiltrar_TextChanged(object sender, TextChangedEventArgs e)
    {
      TextBox ct = e.OriginalSource as TextBox;
      if (ct == null) return;
      ICollectionView vista = ObtenerVista();
      if (vista.CanFilter)
      {
        vista.Filter = delegate(object elemento)
        {
          return ((telefono)elemento).telefono1.Contains(ct.Text);
        };
      }
    }

    private void imFoto_MouseDown(object sender, MouseButtonEventArgs e)
    {
      OpenFileDialog dlg = new OpenFileDialog();
      dlg.Filter = "ficheros jpg (*.jpg)|*.jpg|"+
                   "ficheros jpeg (*.jpeg)|*.jpeg|"+
                   "ficheros png (*.png)|*.png|"+
                   "Todos (*.*)|*.*"; 
      dlg.ShowDialog();

      if (dlg.FileName != null && dlg.FileName.Length > 0)
      {
        byte[] bytes = File.ReadAllBytes(dlg.FileName);
        ICollectionView vista = ObtenerVista();
        telefono regActual = (telefono)vista.CurrentItem;
        if (regActual != null) regActual.foto = bytes;
      }
    }

    private void btGuardar_Click(object sender, RoutedEventArgs e)
    {
      guardarCambios("modificar", null);
    }

    private void guardarCambios(string op, telefono objTfno)
    {
      // Obtener el contexto de objetos
      bd_telefonos2Entities co =
        (odp.ObjectInstance as CProveedorDatosTelefono).ContextoDeObjs;
      // Operación: "modificar", "añadir" o "borrar"
      switch (op)
      {
        case "añadir":
          co.AddTotelefonos(objTfno);
          break;
        case "borrar":
          co.DeleteObject(objTfno);
          break;
      }
      // Enviar los cambios a la base de datos
      try
      {
        co.SaveChanges();
        System.Diagnostics.Debug.WriteLine("Cambios realizados");
      }
      catch (Exception ex)
      {
        System.Diagnostics.Debug.WriteLine(ex.InnerException.Message);
      }
    }

    private void btAñadir_Click(object sender, RoutedEventArgs e)
    {
      PagFunAgregarTelefono pagFunAgregarTelefono =
        new PagFunAgregarTelefono();
      pagFunAgregarTelefono.Return += new ReturnEventHandler<telefono>(
        pagFunAgregarTelefono_Return);
      this.NavigationService.Navigate(pagFunAgregarTelefono);
    }

    private void pagFunAgregarTelefono_Return(object sender, ReturnEventArgs<telefono> e)
    {
      if (e != null)
      {
        ICollectionView vista = ObtenerVista();
        // Añadir el objeto a la colección
        (vista.SourceCollection as List<telefono>).Add(e.Result);
        vista.MoveCurrentToLast();
        // Añadir el objeto a la base de datos
        guardarCambios("añadir", e.Result);
      }
    }

    private void btBorrar_Click(object sender, RoutedEventArgs e)
    {
      // Quitar de la colección el elemento mostrado
      ICollectionView vista = ObtenerVista();
      if (vista.CurrentPosition > -1)
      {
        telefono tfno = (telefono)vista.CurrentItem;
        if (tfno != null)
        {
          int siguientePosActual = (vista.CurrentPosition - 1);
          (vista.SourceCollection as List<telefono>).Remove(tfno);
          vista.Refresh();
          if (siguientePosActual > -1)
            vista.MoveCurrentToPosition(siguientePosActual);
          // Borrar el objeto de la base de datos
          guardarCambios("borrar", tfno);
        }
      }
    }
  }
}
