﻿namespace ApNegociosSL
{
  using System.Windows;
  using System.Windows.Controls;
  using System.Windows.Navigation;
  using ApNegociosSL.LoginUI;

  /// <summary>
  /// Clase <see cref="UserControl"/> que proporciona la IU principal de la aplicación.
  /// </summary>
  public partial class MainPage : UserControl
  {
    /// <summary>
    /// Crea una nueva instancia de <see cref="MainPage"/>.
    /// </summary>
    public MainPage()
    {
      InitializeComponent();
    }

    /// <summary>
    /// Una vez que el Frame navegue, asegúrese de que el <see cref="HyperlinkButton"/> que representa a la página actual esté seleccionado
    /// </summary>
    private void ContentFrame_Navigated(object sender, NavigationEventArgs e)
    {
      foreach (UIElement child in LinksStackPanel.Children)
      {
        HyperlinkButton hb = child as HyperlinkButton;
        if (hb != null && hb.NavigateUri != null)
        {
          if (hb.NavigateUri.ToString().Equals(e.Uri.ToString()))
          {
            VisualStateManager.GoToState(hb, "ActiveLink", true);
          }
          else
          {
            VisualStateManager.GoToState(hb, "InactiveLink", true);
          }
        }
      }
    }

    /// <summary>
    /// Si se produce un error durante la navegación, mostrar una ventana de error
    /// </summary>
    private void ContentFrame_NavigationFailed(object sender, NavigationFailedEventArgs e)
    {
      e.Handled = true;
      ErrorWindow.CreateNew(e.Exception);
    }

    private void ContentFrame_Navigating(object sender, NavigatingCancelEventArgs e)
    {
      // Páginas Home y About
      if (e.Uri.OriginalString == "/Home" ||
          e.Uri.OriginalString == "/About")
        return; // continuar
      // Resto de páginas: Mostrar, Agregar y Borrar
      if (!WebContext.Current.User.IsAuthenticated)
        AccesoDenegado(e);
      // Si está autenticado tiene acceso a Mostrar. Ahora:
      else if (e.Uri.OriginalString != "/Mostrar" &&
               WebContext.Current.User.IsInRole("Registered Users"))
        AccesoDenegado(e);
      else
      {
        // "miembros" o "administradores"
        // Ambos pueden Agregar, pero Borrar sólo los administradores
        if (e.Uri.OriginalString == "/Borrar" &&
            !WebContext.Current.User.IsInRole("administradores"))
          AccesoDenegado(e);
      }
    }

    private void AccesoDenegado(NavigatingCancelEventArgs e)
    {
      ErrorWindow window = new ErrorWindow("Acceso denegado",
        "No está autorizado para acceder a esta página");
      window.Show();
      e.Cancel = true;
    }
  }
}